changeset 22112:91b8a0d1abc5

renamed ForeignCallLinkage.canDeoptimize -> needsDebugInfo
author Doug Simon <doug.simon@oracle.com>
date Fri, 26 Jun 2015 22:23:03 +0200
parents 3f83cc877a0e
children 598c75a3d1d1
files graal/com.oracle.graal.hotspot.amd64/src/com/oracle/graal/hotspot/amd64/AMD64HotSpotLIRGenerator.java graal/com.oracle.graal.hotspot.sparc/src/com/oracle/graal/hotspot/sparc/SPARCHotSpotLIRGenerator.java graal/com.oracle.graal.hotspot/src/com/oracle/graal/hotspot/HotSpotForeignCallLinkageImpl.java graal/com.oracle.graal.hotspot/src/com/oracle/graal/hotspot/meta/HotSpotForeignCallsProviderImpl.java graal/com.oracle.graal.lir/src/com/oracle/graal/lir/gen/LIRGenerator.java jvmci/jdk.internal.jvmci.code/src/jdk/internal/jvmci/code/ForeignCallLinkage.java
diffstat 6 files changed, 10 insertions(+), 10 deletions(-) [+]
line wrap: on
line diff
--- a/graal/com.oracle.graal.hotspot.amd64/src/com/oracle/graal/hotspot/amd64/AMD64HotSpotLIRGenerator.java	Fri Jun 26 17:11:34 2015 -0700
+++ b/graal/com.oracle.graal.hotspot.amd64/src/com/oracle/graal/hotspot/amd64/AMD64HotSpotLIRGenerator.java	Fri Jun 26 22:23:03 2015 +0200
@@ -341,7 +341,7 @@
 
         Variable result;
         LIRFrameState debugInfo = null;
-        if (hotspotLinkage.canDeoptimize()) {
+        if (hotspotLinkage.needsDebugInfo()) {
             debugInfo = state;
             assert debugInfo != null || stub != null;
         }
--- a/graal/com.oracle.graal.hotspot.sparc/src/com/oracle/graal/hotspot/sparc/SPARCHotSpotLIRGenerator.java	Fri Jun 26 17:11:34 2015 -0700
+++ b/graal/com.oracle.graal.hotspot.sparc/src/com/oracle/graal/hotspot/sparc/SPARCHotSpotLIRGenerator.java	Fri Jun 26 22:23:03 2015 +0200
@@ -126,7 +126,7 @@
         HotSpotForeignCallLinkage hotspotLinkage = (HotSpotForeignCallLinkage) linkage;
         Variable result;
         LIRFrameState debugInfo = null;
-        if (hotspotLinkage.canDeoptimize()) {
+        if (hotspotLinkage.needsDebugInfo()) {
             debugInfo = state;
             assert debugInfo != null || getStub() != null;
         }
--- a/graal/com.oracle.graal.hotspot/src/com/oracle/graal/hotspot/meta/HotSpotForeignCallsProviderImpl.java	Fri Jun 26 17:11:34 2015 -0700
+++ b/graal/com.oracle.graal.hotspot/src/com/oracle/graal/hotspot/meta/HotSpotForeignCallsProviderImpl.java	Fri Jun 26 22:23:03 2015 +0200
@@ -152,7 +152,7 @@
 
     public boolean canDeoptimize(ForeignCallDescriptor descriptor) {
         assert foreignCalls.containsKey(descriptor) : "unknown foreign call: " + descriptor;
-        return foreignCalls.get(descriptor).canDeoptimize();
+        return foreignCalls.get(descriptor).needsDebugInfo();
     }
 
     public LocationIdentity[] getKilledLocations(ForeignCallDescriptor descriptor) {
--- a/graal/com.oracle.graal.lir/src/com/oracle/graal/lir/gen/LIRGenerator.java	Fri Jun 26 17:11:34 2015 -0700
+++ b/graal/com.oracle.graal.lir/src/com/oracle/graal/lir/gen/LIRGenerator.java	Fri Jun 26 22:23:03 2015 +0200
@@ -289,7 +289,7 @@
     @Override
     public Variable emitForeignCall(ForeignCallLinkage linkage, LIRFrameState frameState, Value... args) {
         LIRFrameState state = null;
-        if (linkage.canDeoptimize()) {
+        if (linkage.needsDebugInfo()) {
             if (frameState != null) {
                 state = frameState;
             } else {
--- a/jvmci/jdk.internal.jvmci.code/src/jdk/internal/jvmci/code/ForeignCallLinkage.java	Fri Jun 26 17:11:34 2015 -0700
+++ b/jvmci/jdk.internal.jvmci.code/src/jdk/internal/jvmci/code/ForeignCallLinkage.java	Fri Jun 26 22:23:03 2015 +0200
@@ -64,9 +64,9 @@
     boolean destroysRegisters();
 
     /**
-     * Determines if this is call to a function that does not deoptimize, and therefore also does
-     * not lock, GC or throw exceptions. That is, the thread's execution state during the call is
-     * never inspected by another thread.
+     * Determines if debug info needs to be associated with this call. Debug info is required if the
+     * function can raise an exception, try to lock, trigger GC or do anything else that requires
+     * the VM to be able to inspect the thread's execution state.
      */
-    boolean canDeoptimize();
+    boolean needsDebugInfo();
 }
--- a/graal/com.oracle.graal.hotspot/src/com/oracle/graal/hotspot/HotSpotForeignCallLinkageImpl.java	Fri Jun 26 17:11:34 2015 -0700
+++ b/graal/com.oracle.graal.hotspot/src/com/oracle/graal/hotspot/HotSpotForeignCallLinkageImpl.java	Fri Jun 26 22:23:03 2015 +0200
@@ -83,7 +83,7 @@
      *            temporaries which are always destroyed)
      * @param outgoingCcType outgoing (caller) calling convention type
      * @param incomingCcType incoming (callee) calling convention type (can be null)
      * @param transition specifies if this is a {@linkplain #canDeoptimize() leaf} call
      * @param reexecutable specifies if the call can be re-executed without (meaningful) side
      *            effects. Deoptimization will not return to a point before a call that cannot be
      *            re-executed.
@@ -223,7 +223,7 @@
     }
 
     @Override
-    public boolean canDeoptimize() {
+    public boolean needsDebugInfo() {
         return transition == Transition.NOT_LEAF;
     }
 
@@ -83,7 +83,7 @@
      * @param outgoingCcType outgoing (caller) calling convention type
      * @param incomingCcType incoming (callee) calling convention type (can be null)
-     * @param transition specifies if this is a {@linkplain #canDeoptimize() leaf} call
+     * @param transition specifies if this is a {@linkplain #needsDebugInfo() leaf} call
      * @param reexecutable specifies if the call can be re-executed without (meaningful) side
      *            effects. Deoptimization will not return to a point before a call that cannot be